UartBaudRateGeneratorConfig

Struct UartBaudRateGeneratorConfig 

pub struct UartBaudRateGeneratorConfig { /* private fields */ }
Available on crate feature unstable only.
Configures the UART0_BAUD_RATE_GENERATOR clock node.

The output is calculated as OUTPUT = (FUNCTION_CLOCK * 16) / (integral * 16 + fractional).

Implementations

Source

impl UartBaudRateGeneratorConfig

pub const fn new(fractional: u32, integral: u32) -> Self

Creates a new configuration for the BAUD_RATE_GENERATOR clock node.

Panics

Panics if the fractional value is outside the valid range (0 ..= 15).

Panics if the integral value is outside the valid range (0 ..= 4095).